'use strict';

var ListaNFSefazController = angular.module('ListaNFSefazController', []);

ListaNFSefazController.controller('ListaNFSefazCtrl', ['$scope', '$routeParams', 'Compra', 'Construcao', 'Material', 'Fonte', 'Categoria', 'UploadApp', 'CacheApp',
  ($scope, $routeParams, Compra, Construcao, Material, Fonte, Categoria, UploadApp, CacheApp) => {
    
    $scope.setNotaSefazConstrucao = (nota) => {
        var construcao = $scope.construcoes.filter(c => c.Id == nota.ObraSelecionada.id)[0]
        var params = {
            IdNotaFiscalSefaz: nota.IdNotaFiscalSefaz,
            IdConstrucao: nota.ObraSelecionada.id,
            IdEtapa: nota.EtapaNFSelecionada ? (nota.EtapaNFSelecionada.Id == 0 ? undefined : nota.EtapaNFSelecionada.Id) : undefined,
            IdComposicao: nota.ComposicaoNFSelecionada ? (nota.ComposicaoNFSelecionada.Id == 0 ? undefined : nota.ComposicaoNFSelecionada.Id) : undefined,
            IdClienteDono: construcao.IdClienteDono,
            Fonte: nota.FonteNFSelecionada ? nota.FonteNFSelecionada.IdFonte : undefined,
            Categoria: nota.CategoriaNFSelecionada ? nota.CategoriaNFSelecionada.IdCategoria : undefined,
            ArquivoXML: nota.ArquivoXML,
            ArquivoPDF: nota.NomeArquivoPDF
        }
        Compra.setNotaSefazConstrucao(params,
            (data) => {
                if (data.Code != 0) {
                    $scope.msgBoxAtencao("Atenção", data.Description, null);
                }
                else {
                    $scope.loadNFSefaz()
                }
            }
        );
    }

    $scope.editarNFSefaz = (nota) => {
        if (nota.DataCancelado)
            return
        if (!nota.nfeLancada && nota.IdConstrucao) {
            if (!nota.detalhe)
                $scope.detalharNota(nota)
            nota.detalhe = !nota.detalhe
        }
        else {
            nota.Editar = !nota.Editar
            if (nota.Editar) {
                if (nota.nfeLancada) {
                    $scope.getEtapasNF(nota.IdConstrucao, nota)
                }
                else
                    $scope.getEtapasNF(0, nota)
            }
        }
    }

    $scope.cancelarNFSefaz = (nota) => {
        $scope.msgBoxPergunta('Descartar a nota?', 'A nota não será mais utilizada para lançamento.'
            , () => {
                Compra.cancelaNotaFiscalSefaz({IdNotaFiscalSefaz: nota.IdNotaFiscalSefaz},
                    (data) => {
                        $scope.loadNFSefaz()
                    });
            }
            , () => {
            });
    }

    $scope.excluirNFSefaz = (nota) => {
        $scope.msgBoxPergunta('Excluir a nota fiscal?', 'A nota será excluída na obra que foi alocada.'
            , () => {
                Compra.delNotaFiscalSefaz({IdNotaFiscalSefaz: nota.IdNotaFiscalSefaz},
                    (data) => {
                        $scope.loadNFSefaz()
                    });
            }
            , () => {
            });
    }

    $scope.substituirNFSefaz = (nota) => {
        $scope.msgBoxPergunta('Substituir a nota fiscal?', 'O lançamento financeiro será excluído e substituído por esta nota fiscal.'
            , () => {
                Compra.delNotaFiscal(nota.IdNotaFiscal,
                    (data) => {
                        $scope.setNotaSefazConstrucao(nota)
                    });
            }
            , () => {
            });
    }

    $scope.setSefazLancamento = (nota) => {
        var construcao = $scope.construcoes.filter(c => c.Id == nota.ObraSelecionada.id)[0]
        var params = {
            IdNotaFiscalSefaz: nota.IdNotaFiscalSefaz,
            IdConstrucao: nota.ObraSelecionada.id,
            IdNotaFiscal: nota.IdNotaFiscal,
            IdEtapa: nota.EtapaNFSelecionada.Id == 0 ? undefined : nota.EtapaNFSelecionada.Id,
            IdComposicao: nota.ComposicaoNFSelecionada.Id == 0 ? undefined : nota.ComposicaoNFSelecionada.Id,
            IdClienteDono: construcao.IdClienteDono,
            Fonte: nota.FonteNFSelecionada.IdFonte,
            Categoria: nota.CategoriaNFSelecionada.IdCategoria
        }
        Compra.setSefazLancamento(params,
            (data) => {
                if (data.Code != 0) {
                    $scope.msgBoxAtencao("Atenção", data.Description, null);
                }
                else {
                    $scope.loadNFSefaz()
                }
            }
        );
    }

    $scope.getNotaFiscalSefaz = () => {
        var params = {
            IdCliente: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : $scope.sessao.IdCliente,
            Cnpj: $scope.certificadoSelecionado.Cnpj,
            DataInicio: $scope.DataInicio.toISOString().substring(0, 10),
            DataFim: $scope.DataFim.toISOString().substring(0, 10),
            Index: $scope.paginacao.Index,
            Pages: $scope.paginacao.Pages
        }
        $scope.paginacao.Load = true;
        Compra.getNotaFiscalSefaz(params,
            (data) => {
                if (!$scope.listaNFAll) {
                    $scope.listaNFAll = []

                    $scope.total = {
                        SemVinculo: 0,
                        LancIdent: 0,
                        Duplicado: 0,
                        Vinculado: 0
                    }

                }

                if (data.Instance)
                    data.Instance.forEach(l => {
                        l.DataEmissao = CacheApp.getData(l.DataEmissao)
                        if (l.IdConstrucao) {
                            var obra = $scope.construcoes.find(c => c.Id == l.IdConstrucao);
                            if (obra)
                                l.ObraSelecionada = {
                                    id: obra.Id, 
                                    model: obra.Titulo, 
                                    label: obra.Titulo,
                                    tipo: obra.Tipo,
                                    checked: true
                                }
                        }
                        l.CategoriaNFSelecionada = {IdCategoria: 0};
                        l.FonteNFSelecionada = {IdFonte: 0};
                        l.ComposicaoNFSelecionada = {Id: 0};

                        if (!l.IdConstrucao) $scope.total.SemVinculo += 1
                        if (l.nfeLancada) $scope.total.LancIdent += 1
                        if (l.Duplicado) $scope.total.Duplicado += 1

                        $scope.listaNFAll.push(l)
                    })

                $scope.listaNF = $scope.listaNFAll
                $scope.paginacao.Load = false
            });
    }

    $scope.loadNFSefaz = () => {
        $scope.inicializaPaginacao()
        $scope.getNotaFiscalSefaz()
    }

    $scope.inicializaPaginacao = () => {
        $scope.listaNF = undefined;
        $scope.listaNFAll = undefined;
        $scope.paginacao = {
            Index: 0,
            Pages: 20
        };
    }

    $scope.getListaConstrucao = (callBack) => {
        var params = { 
            Tipo: 0, 
            IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined
        }
        Construcao.getListaObras(params,
            (data) => {
                $scope.construcoes = data.Instance.filter(c => c.Acessos && c.Acessos.indexOf('GET_FINANCEIRO') >= 0)
                callBack()
            }
        );
    }

    $scope.selecionaObra = (nota) => {
        if (Array.isArray(nota.ObraSelecionada))
            return
        $scope.getEtapasNF(nota.ObraSelecionada.id, nota)
    }

    $scope.getListaSituacao = () => {
        $scope.listaSituacao = [
            {Id: 0, Nome: 'Todas'},
            {Id: 1, Nome: 'Sem vínculo'},
            {Id: 2, Nome: 'Vinculada'},
            {Id: 3, Nome: 'Lançamento identificado sem vínculo'},
            {Id: 4, Nome: 'Cancelada'},
        ]
        $scope.situacaoSelecionada = {Id: 0}
    }

    $scope.baixarpdf = (pdf) => {
        window.open(pdf,'_blank');
    }

    $scope.getListaFonteNF = () => {
        var params = {IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined}
        Fonte.getListaFonte(params,
            (data) => {
                $scope.listaFonteNF = data.Instance;
                $scope.listaFonteNF.unshift({IdFonte: 0, Nome: 'Sem Fonte'});
            });
    }

    $scope.getListaCategoriaNF = () => {
        Categoria.getListaCategoria($scope.sessao.IdCliente,
            (data) => {
                $scope.listaCategoriaNF = data.Instance;
                $scope.listaCategoriaNF.unshift({IdCategoria: 0, Nome: 'Sem Categoria'});
            });
    }

    $scope.getEtapasNF = (IdConstrucao, nota) => {
        $scope.etapasNF = [];
        $scope.composicoesNF = [{Id: 0, Ordem: '', Nome: 'Sem Composição'}];
        Construcao.getEtapasConstrucao(IdConstrucao,
            (data) => {
                $scope.etapasNF = data.Instance;
                $scope.etapasNF.unshift({Id: 0, Ordem: '', Descricao: 'Sem Etapa'});
                nota.EtapaNFSelecionada = {Id: 0};
            });
    }

    $scope.getComposicoesNF =  (item, nota) => {
        if (!item || item.Id == 0) {
            $scope.composicoesNF = [{Id: 0, Ordem: '', Nome: 'Sem Composição'}];
            return;
        }
        item.IdEtapa = item.Id;
        Material.getListaMaterialAvanco(
            item.IdConstrucao,
            item.IdEtapa,
            '',
             (data) => {
                $scope.composicoesNF = data.Instance;
                $scope.composicoesNF.unshift({Id: 0, Ordem: '', Nome: 'Sem Composição'});
                nota.ComposicaoNFSelecionada = {Id: 0};
            });
    }

    $scope.getListaFonteNF = () => {
        var params = {IdClienteAdmin: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : undefined}
        Fonte.getListaFonte(params,
            (data) => {
                $scope.listaFonteNF = data.Instance;
                $scope.listaFonteNF.unshift({IdFonte: 0, Nome: 'Sem Fonte'});
            });
    }

    $scope.getCertificados = (callBack) => {
        var params = {
            IdCliente: $scope.sessao.ContaAdmin ? $scope.sessao.IdClienteAdmin : $scope.sessao.IdCliente
        }
        Compra.getCertificados(params,
            (data) => {
                $scope.Certificados = data.Instance
                callBack()
            });
    }

    $scope.$on('atualizaListaCertificado', (event, args) => {
        $scope.getCertificados(()=> {})
    });

    $scope.detalharNota = (nota) => {
        $scope.construcaoSel = $scope.construcoes.filter(c => c.Id == nota.IdConstrucao)[0]
        Compra.getNotasFiscais($scope.construcaoSel.Id, nota.IdNotaFiscal,
            (data) => {
                $scope.notafiscalSel = data.Instance[0]
                $scope.notafiscalSel.DataEmissao = CacheApp.getData($scope.notafiscalSel.DataEmissao);
                $scope.notafiscalSel.DataPagamento = CacheApp.getData($scope.notafiscalSel.DataPagamento);
                $scope.notafiscalSel.DescricaoNF = $scope.notafiscalSel.Descricao;
                $scope.notafiscalSel.sefaz = true
                $scope.notafiscalSel.BDI = $scope.notafiscalSel.BDI ? $scope.notafiscalSel.BDI.data[0] == 1 : false;

                nota.detalhe = true
                nota.HtmlNotaFiscal = `
                    <manternotafiscal 
                        rd-notafiscal="notafiscalSel"
                        rd-obra="construcaoSel"
                        rd-notasfiscais="[]"
                        rd-fornecedor="{}">
                    </manternotafiscal>`
        });
    };

    $scope.setFiltroSituacao = (situacao) => {
        if (situacao.Id == 0)
            $scope.listaNF = $scope.listaNFAll
        else
            $scope.listaNF = $scope.listaNFAll.filter(l => l.Situacao == situacao.Nome)
    }

    $scope.adicionaCertificado = () => {
        $('#BoxCertificado').modal('show');
    }

    $scope.AcessoAndroid($routeParams, (sim) => {
        $scope.sessao = CacheApp.getSessao()

        var dataIni = new Date()
        dataIni.setDate(dataIni.getDate() - 60)
        $scope.DataInicio = CacheApp.getData(dataIni)
        $scope.DataFim = CacheApp.getData(Date.now())
        $scope.DataInicioProc = CacheApp.getData(Date.now())

        $scope.getListaSituacao()
        $scope.getCertificados(()=>{
            $scope.getListaConstrucao(() => {
                $scope.getListaFonteNF()
                $scope.getListaCategoriaNF()
                if ($scope.Certificados && $scope.Certificados.length > 0) {
                    $scope.certificadoSelecionado = $scope.Certificados[0]
                    $scope.loadNFSefaz()
                }
            })
        })

    });
  
}]);
